@@ -1,9 +1,12 @@
 <?php
+
 /*
    Empty Trash - A Plugin for SqurrelMail
-   Version: 1.2 
-   Version Date: 04-Jul-2003
-   Author: Derek Battams <derek@battams.ca>
+   Version: 1.3
+   Version Date: 29-Jun-2004
+   Authors: Derek Battams <derek@battams.ca>
+            Paul Lesneiwski <pdontthink@angrynerds.com>
+
    Please see the README file for further information
 
    File: setup.php
@@ -14,6 +17,10 @@ DATE          AUTHOR   CHANGE
 03-Nov-2002   ddb      Bug fixes; audit for SM >= 1.2.8 compatibility
 04-Jul-2003   pl       New setup.php format for faster overall SM performance
                        Updated for SM version reporting API
+29-Jun-2004   pl       Created config file to allow administrative control over
+                       deletion criteria.
+                       Fixed time-based criteria to measure days instead of weeks
+                       (which had an inadvertent bug)
 
 */
 
@@ -27,7 +34,7 @@ function squirrelmail_plugin_init_empty_trash()
 
 function empty_trash_version()
 {
-   return '1.2';
+   return '1.3';
 }
 
 function incCounter()
